==> haskell-yesod-core-1.6.5-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.6.5
id: yesod-core-1.6.5-32xOk1nCBu0I44htNBtOl2
key: yesod-core-1.6.5-32xOk1nCBu0I44htNBtOl2
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
abi: 1ea912c8bb8ceac914485e60e466bdfb
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-core-1.6.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-core-1.6.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/yesod-core-1.6.5
hs-libraries: HSyesod-core-1.6.5-32xOk1nCBu0I44htNBtOl2
depends:
    base-4.11.1.0 time-1.8.0.2 wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx
    wai-extra-3.0.22.1-KJlyHFpeYikDUiMv1Gg7on bytestring-0.10.8.2
    text-1.2.3.0 template-haskell-2.13.0.0
    path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
    shakespeare-2.0.15-AYGkoAAVr8N3J71KcHfMWO transformers-0.5.5.0
    mtl-2.2.2 clientsession-0.9.1.2-CsjY4PebaSWFF9coJOobvb
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh containers-0.5.11.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra parsec-3.1.13.0
    directory-1.3.1.5 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    wai-logger-2.3.2-8wneV8Zq5jX32yd00otpUr
    monad-logger-0.3.28.5-DbEbvv2YHxAh1lF2yzVCT
    conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    warp-3.2.22-HY9tYerhh1X6Gd8jArtQ3A
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    conduit-extra-1.3.0-87goSKbnlY0JxObgNuqdId deepseq-1.4.3.0
    deepseq-generics-0.2.0.0-1vEsN63mezSGRpRYvUTdz8
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
    auto-update-0.1.4-7k5Okr80TfS9UGlvnbDZr0
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
    unliftio-0.2.7.0-EzYU21zpVB1AicVWwOW57E
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx=a10b0b451ac20f27f6160db52b013dec
             wai-extra-3.0.22.1-KJlyHFpeYikDUiMv1Gg7on=a72ffbe2bfa51351bf53d691c5b04e1a
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW=e495b63bc307ad3b3433d06ac8057b64
             shakespeare-2.0.15-AYGkoAAVr8N3J71KcHfMWO=2ba329459f9f7720efac369c1b63f65b
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             clientsession-0.9.1.2-CsjY4PebaSWFF9coJOobvb=033730dfe5d9bc5b4ae2a99fd1c3c632
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=77866f631eefa2be10fa7c88fcec53a0
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=0526158ceb7aa285fbb07f1a82b14796
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=74f385e9dd50fadd4b5101789b2372bf
             wai-logger-2.3.2-8wneV8Zq5jX32yd00otpUr=27202fb50a9e9bfc25ee18609d6e791b
             monad-logger-0.3.28.5-DbEbvv2YHxAh1lF2yzVCT=d96ebb6eedd950e96670a90e52539649
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             warp-3.2.22-HY9tYerhh1X6Gd8jArtQ3A=6e2c18e816108018f85e88f517ed2b28
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             conduit-extra-1.3.0-87goSKbnlY0JxObgNuqdId=15e73479198449396f6e4efa6ea25606
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             deepseq-generics-0.2.0.0-1vEsN63mezSGRpRYvUTdz8=91ae6467772d86e14ec11fa50e7c1dbd
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=a76404d2410541ab4c0cf63ee4e3a316
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=ebc90d010e749320c5d2c76b47a69695
             auto-update-0.1.4-7k5Okr80TfS9UGlvnbDZr0=3a6a6105842b972d51861c6c93221bbc
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=1b344c82815219929c6d7eafd49ac50e
             unliftio-0.2.7.0-EzYU21zpVB1AicVWwOW57E=034ebba48206f0450a38c61533ce67c7
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.5-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.6.5
id: yesod-core-1.6.5-5JtbZKSxzjqR6tD6z8kSo
key: yesod-core-1.6.5-5JtbZKSxzjqR6tD6z8kSo
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
abi: 804195ab12393543e6e312d52e756424
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-core-1.6.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-core-1.6.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/yesod-core-1.6.5
hs-libraries: HSyesod-core-1.6.5-5JtbZKSxzjqR6tD6z8kSo
depends:
    base-4.11.1.0 time-1.8.0.2 wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh
    wai-extra-3.0.22.1-7QmLNxSLju21lmv1opY1EV bytestring-0.10.8.2
    text-1.2.3.0 template-haskell-2.13.0.0
    path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
    shakespeare-2.0.15-AYGkoAAVr8N3J71KcHfMWO transformers-0.5.5.0
    mtl-2.2.2 clientsession-0.9.1.2-CsjY4PebaSWFF9coJOobvb
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh containers-0.5.11.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra parsec-3.1.13.0
    directory-1.3.1.5 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    wai-logger-2.3.2-FCFgsbDcNYEKCNk20vjb4i
    monad-logger-0.3.28.5-Le3NyXl6lgo8CJsdX6ybpJ
    conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    warp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    conduit-extra-1.3.0-GaxULXhX2UP3bPKmBvOmT deepseq-1.4.3.0
    deepseq-generics-0.2.0.0-1vEsN63mezSGRpRYvUTdz8
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
    auto-update-0.1.4-7k5Okr80TfS9UGlvnbDZr0
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
    unliftio-0.2.7.0-EzYU21zpVB1AicVWwOW57E
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh=3c531a9c9dceb5cf3884617d81bc336d
             wai-extra-3.0.22.1-7QmLNxSLju21lmv1opY1EV=b4aa7ea7b4308af6e795a2fe46a71976
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW=e495b63bc307ad3b3433d06ac8057b64
             shakespeare-2.0.15-AYGkoAAVr8N3J71KcHfMWO=2ba329459f9f7720efac369c1b63f65b
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             clientsession-0.9.1.2-CsjY4PebaSWFF9coJOobvb=033730dfe5d9bc5b4ae2a99fd1c3c632
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=77866f631eefa2be10fa7c88fcec53a0
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=0526158ceb7aa285fbb07f1a82b14796
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=74f385e9dd50fadd4b5101789b2372bf
             wai-logger-2.3.2-FCFgsbDcNYEKCNk20vjb4i=cde76aa08f59d955e2ab0a4812969f6d
             monad-logger-0.3.28.5-Le3NyXl6lgo8CJsdX6ybpJ=1cc2cf87695ad5c5895a81aa46ff58bd
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             warp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W=1d9baf1f171c173416edccd3cf032c07
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             conduit-extra-1.3.0-GaxULXhX2UP3bPKmBvOmT=49651e9ab9985fbad79d2cfea10c977e
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             deepseq-generics-0.2.0.0-1vEsN63mezSGRpRYvUTdz8=91ae6467772d86e14ec11fa50e7c1dbd
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=a76404d2410541ab4c0cf63ee4e3a316
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=ebc90d010e749320c5d2c76b47a69695
             auto-update-0.1.4-7k5Okr80TfS9UGlvnbDZr0=3a6a6105842b972d51861c6c93221bbc
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=1b344c82815219929c6d7eafd49ac50e
             unliftio-0.2.7.0-EzYU21zpVB1AicVWwOW57E=034ebba48206f0450a38c61533ce67c7
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
